/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef ATOMICOPSCONFIG_H_
#define ATOMICOPSCONFIG_H_

#if (defined(__i386__) || defined(__x86_64__)) && defined(__GNUC__)

#  define ATOMIC_OPS_X86_GNUC

#elif defined(_M_IX86) && defined(_MSC_VER)

#  define ATOMIC_OPS_X86_MSC

#elif (defined(__PPC__) || defined(__ppc__)) && defined(__GNUC__)

#  define ATOMIC_OPS_PPC_GNUC

#else

#  define ATOMIC_OPS_GENERIC

#endif

#if !defined(ATOMIC_OPS_GENERIC)
#  define ATOMIC_OPS_OPTIMIZED
#endif

#endif
